@@ -26,6 +26,7 @@ class Client:
         self.base_url = config.get("global/base_url")
         self.default_team = default_team or config.get("global/default_team")
         self.features: dict = {}
+        self._newer_version = None
 
     def get(
         self, endpoint: str, team: Optional[str] = None, retry: bool = False, raw: bool = False, debug: bool = False
@@ -396,15 +397,19 @@ class Client:
         dict
         Contains the Content-Type and Authorization token
         """
-        header = {"Content-Type": "application/json"}
+        headers = {"Content-Type": "application/json"}
         api_key = None
         team_config = self.config.get_team(team or self.default_team, raise_on_invalid_team=False)
         if team_config:
             api_key = team_config.get("api_key")
 
         if api_key is not None and len(api_key) > 0:
-            header["Authorization"] = f"ApiKey {api_key}"
-        return header
+            headers["Authorization"] = f"ApiKey {api_key}"
+
+        from darwin import __version__
+
+        headers["User-Agent"] = f"darwin-py/{__version__}"
+        return headers
 
     @classmethod
     def local(cls, team_slug: Optional[str] = None):
@@ -489,8 +494,7 @@ class Client:
         """Returns the default base url"""
         return os.getenv("DARWIN_BASE_URL", "https://darwin.v7labs.com")
 
-    @staticmethod
-    def _decode_response(response, debug: bool = False):
+    def _decode_response(self, response, debug: bool = False):
         """Decode the response as JSON entry or return a dictionary with the error
 
         Parameters
@@ -505,6 +509,10 @@ class Client:
         dict
         JSON decoded entry or error
         """
+
+        if "latest-darwin-py" in response.headers:
+            self._handle_latest_darwin_py(response.headers["latest-darwin-py"])
+
         try:
             return response.json()
         except ValueError:
@@ -513,5 +521,25 @@ class Client:
             response.close()
             return {"error": "Response is not JSON encoded", "status_code": response.status_code, "text": response.text}
 
+    def _handle_latest_darwin_py(self, server_latest_version):
+        try:
+
+            def parse_version(version_str):
+                return tuple([int(x) for x in version_str.split(".")])
+
+            from darwin import __version__
+
+            current_version = parse_version(__version__)
+            latest_version = parse_version(server_latest_version)
+            if current_version >= latest_version:
+                return
+            self._newer_version = latest_version
+        except:
+            pass
+
+    @property
+    def newer_darwin_version(self):
+        return self._newer_version
+
     def __str__(self):
         return f"Client(default_team={self.default_team})"
